@@ -161,12 +161,12 @@ class DNode(object):
         if ret != 0:
             self.context.error('validation failed')
 
-    def dump_str(self, fmt,
-                 with_siblings=False,
-                 pretty=False,
-                 include_implicit_defaults=False,
-                 trim_default_values=False,
-                 keep_empty_containers=False):
+    def print_mem(self, fmt,
+                  with_siblings=False,
+                  pretty=False,
+                  include_implicit_defaults=False,
+                  trim_default_values=False,
+                  keep_empty_containers=False):
         flags = printer_flags(
             with_siblings=with_siblings, pretty=pretty,
             include_implicit_defaults=include_implicit_defaults,
@@ -178,19 +178,19 @@ class DNode(object):
         if ret != 0:
             raise self.context.error('cannot print node')
         try:
-            if fmt == 'lyb':
+            if fmt == lib.LYD_LYB:
                 # binary format, do not convert to unicode
-                return ffi.string(buf[0])
-            return c2str(buf[0])
+                return c2str(buf[0], decode=False)
+            return c2str(buf[0], decode=True)
         finally:
             lib.free(buf[0])
 
-    def dump_file(self, fileobj, fmt,
-                  with_siblings=False,
-                  pretty=False,
-                  include_implicit_defaults=False,
-                  trim_default_values=False,
-                  keep_empty_containers=False):
+    def print_file(self, fileobj, fmt,
+                   with_siblings=False,
+                   pretty=False,
+                   include_implicit_defaults=False,
+                   trim_default_values=False,
+                   keep_empty_containers=False):
         flags = printer_flags(
             with_siblings=with_siblings, pretty=pretty,
             include_implicit_defaults=include_implicit_defaults,
@@ -201,6 +201,67 @@ class DNode(object):
         if ret != 0:
             raise self.context.error('cannot print node')
 
+    def print_dict(self, strip_prefixes=True, absolute=True,
+                   with_siblings=False, include_implicit_defaults=False,
+                   trim_default_values=False, keep_empty_containers=False):
+        """
+        Convert a DNode object to a python dictionary.
+
+        :arg DNode dnode:
+            The data node to convert.
+        :arg bool strip_prefixes:
+            If True (the default), module prefixes are stripped from dictionary
+            keys. If False, dictionary keys are in the form ``<module>:<name>``.
+        :arg bool absolute:
+            If True (the default), always return a dictionary containing the
+            complete tree starting from the root.
+        :arg bool with_siblings:
+            If True, include the node's siblings.
+        :arg bool include_implicit_defaults:
+            Include implicit default nodes.
+        :arg bool trim_default_values:
+            Exclude nodes with the value equal to their default value.
+        :arg bool keep_empty_containers:
+            Preserve empty non-presence containers.
+        """
+        flags = printer_flags(
+            include_implicit_defaults=include_implicit_defaults,
+            trim_default_values=trim_default_values,
+            keep_empty_containers=keep_empty_containers)
+
+        def _to_dict(node, parent_dic):
+            if not lib.lyd_toprint(node._node, flags):
+                return
+            if strip_prefixes:
+                name = node.name()
+            else:
+                name = '%s:%s' % (node.module().name(), node.name())
+            if isinstance(node, DList):
+                list_element = {}
+                for child in node:
+                    _to_dict(child, list_element)
+                parent_dic.setdefault(name, []).append(list_element)
+            elif isinstance(node, (DContainer, DRpc)):
+                container = {}
+                for child in node:
+                    _to_dict(child, container)
+                parent_dic[name] = container
+            elif isinstance(node, DLeafList):
+                parent_dic.setdefault(name, []).append(node.value())
+            elif isinstance(node, DLeaf):
+                parent_dic[name] = node.value()
+
+        dic = {}
+        dnode = self
+        if absolute:
+            dnode = dnode.root()
+        if with_siblings:
+            for sib in dnode.siblings():
+                _to_dict(sib, dic)
+        else:
+            _to_dict(dnode, dic)
+        return dic
+
     def free(self, with_siblings=True):
         try:
             if with_siblings:
@@ -296,69 +357,6 @@ class DLeafList(DLeaf):
     pass
 
 
-#------------------------------------------------------------------------------
-def dnode_to_dict(dnode, strip_prefixes=True, absolute=True,
-                  with_siblings=False, include_implicit_defaults=False,
-                  trim_default_values=False, keep_empty_containers=False):
-    """
-    Convert a DNode object to a python dictionary.
-
-    :arg DNode dnode:
-        The data node to convert.
-    :arg bool strip_prefixes:
-        If True (the default), module prefixes are stripped from dictionary
-        keys. If False, dictionary keys are in the form ``<module>:<name>``.
-    :arg bool absolute:
-        If True (the default), always return a dictionary containing the
-        complete tree starting from the root.
-    :arg bool with_siblings:
-        If True, include the node's siblings.
-    :arg bool include_implicit_defaults:
-        Include implicit default nodes.
-    :arg bool trim_default_values:
-        Exclude nodes with the value equal to their default value.
-    :arg bool keep_empty_containers:
-        Preserve empty non-presence containers.
-    """
-    flags = printer_flags(
-        include_implicit_defaults=include_implicit_defaults,
-        trim_default_values=trim_default_values,
-        keep_empty_containers=keep_empty_containers)
-
-    def _to_dict(node, parent_dic):
-        if not lib.lyd_toprint(node._node, flags):
-            return
-        if strip_prefixes:
-            name = node.name()
-        else:
-            name = '%s:%s' % (node.module().name(), node.name())
-        if isinstance(node, DList):
-            list_element = {}
-            for child in node:
-                _to_dict(child, list_element)
-            parent_dic.setdefault(name, []).append(list_element)
-        elif isinstance(node, (DContainer, DRpc)):
-            container = {}
-            for child in node:
-                _to_dict(child, container)
-            parent_dic[name] = container
-        elif isinstance(node, DLeafList):
-            parent_dic.setdefault(name, []).append(node.value())
-        elif isinstance(node, DLeaf):
-            parent_dic[name] = node.value()
-
-    dic = {}
-    if dnode:
-        if absolute:
-            dnode = dnode.root()
-        if with_siblings:
-            for sib in dnode.siblings():
-                _to_dict(sib, dic)
-        else:
-            _to_dict(dnode, dic)
-    return dic
-
-
 #------------------------------------------------------------------------------
 def dict_to_dnode(dic, schema, parent=None, rpc_input=False, rpc_output=False):
     """
@@ -464,7 +462,6 @@ def dict_to_dnode(dic, schema, parent=None, rpc_input=False, rpc_output=False):
 
     if parent is not None:
         # go back to the root of the created tree
-        while parent.parent() is not None:
-            parent = parent.parent()
+        parent = parent.root()
 
     return parent
