@@ -97,9 +97,9 @@ class Module(object):
         return iter_children(self.context, self._module, types=types)
 
     def __str__(self):
-        return self.dump_str()
+        return self.name()
 
-    def dump_str(self, fmt='tree', path=None):
+    def print_mem(self, fmt='tree', path=None):
         fmt = schema_out_format(fmt)
         buf = ffi.new('char **')
         ret = lib.lys_print_mem(buf, self._module, fmt, str2c(path), 0, 0)
@@ -110,13 +110,34 @@ class Module(object):
         finally:
             lib.free(buf[0])
 
-    def dump_file(self, fileobj, fmt='tree', path=None):
+    def print_file(self, fileobj, fmt='tree', path=None):
         fmt = schema_out_format(fmt)
         ret = lib.lys_print_fd(
             fileobj.fileno(), self._module, fmt, str2c(path), 0, 0)
         if ret != 0:
             raise self.context.error('cannot print module')
 
+    def parse_data_dict(self, dic, parent=None,
+                        rpc_input=False, rpc_output=False):
+        """
+        Convert a python dictionary to a DNode object following the schema of
+        this module. The returned value is always a top-level data node (i.e.:
+        without parent).
+
+        :arg dict dic:
+            The python dictionary to convert.
+        :arg DNode parent:
+            Optional parent to update. If not specified a new top-level DNode
+            will be created.
+        :arg bool rpc_input:
+            If True, dic will be parsed by looking in the rpc input nodes.
+        :arg bool rpc_output:
+            If True, dic will be parsed by looking in the rpc output nodes.
+        """
+        from .data import dict_to_dnode  # circular import
+        return dict_to_dnode(dic, self, parent=parent,
+                             rpc_input=rpc_input, rpc_output=rpc_output)
+
 
 #------------------------------------------------------------------------------
 class Revision(object):
@@ -709,6 +730,27 @@ class SNode(object):
     def __str__(self):
         return self.name()
 
+    def parse_data_dict(self, dic, parent=None,
+                        rpc_input=False, rpc_output=False):
+        """
+        Convert a python dictionary to a DNode object following the schema of
+        this module. The returned value is always a top-level data node (i.e.:
+        without parent).
+
+        :arg dict dic:
+            The python dictionary to convert.
+        :arg DNode parent:
+            Optional parent to update. If not specified a new top-level DNode
+            will be created.
+        :arg bool rpc_input:
+            If True, dic will be parsed by looking in the rpc input nodes.
+        :arg bool rpc_output:
+            If True, dic will be parsed by looking in the rpc output nodes.
+        """
+        from .data import dict_to_dnode  # circular import
+        return dict_to_dnode(dic, self, parent=parent,
+                             rpc_input=rpc_input, rpc_output=rpc_output)
+
     NODETYPE_CLASS = {}
 
     @classmethod
